@@ -19,4 +19,8 @@ class User(UserBaseModal):
     @classmethod
     def __meta__(self):
         
-        return ('id', 'username', 'email')
\ No newline at end of file
+        return ('id', 'username', 'email')
+    
+    
+    def __str__(self) -> str:
+        return self.username
\ No newline at end of file
